"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventBridgeAdapter = exports.__ΩEventBridgeEventAll = exports.__ΩEventBridgeOptions = void 0;
const { __ΩAdapterRequest } = require('../../contracts');
const { __ΩIEmptyResponse } = require('../../core');
const { __ΩOnErrorProps } = require('../../contracts');
const core_1 = require("../../core");
const __ΩEventBridgeOptions = ['eventBridgeForwardPath', 'eventBridgeForwardMethod', 'P&4!8&4"8M'];
exports.__ΩEventBridgeOptions = __ΩEventBridgeOptions;
const __ΩEventBridgeEventAll = ['"'];
exports.__ΩEventBridgeEventAll = __ΩEventBridgeEventAll;
/**
 * The adapter to handle requests from AWS EventBridge (Cloudwatch Events).
 *
 * The option of `responseWithErrors` is ignored by this adapter and we always call `resolver.fail` with the error.
 *
 * {@link https://docs.aws.amazon.com/lambda/latest/dg/services-cloudwatchevents.html | Event Reference}
 *
 * @example
 * ```typescript
 * const eventBridgeForwardPath = '/your/route/eventbridge'; // default /eventbridge
 * const eventBridgeForwardMethod = 'POST'; // default POST
 * const adapter = new EventBridgeAdapter({ eventBridgeForwardPath, eventBridgeForwardMethod });
 * ```
 *
 * @breadcrumb Adapters / AWS / EventBridgeAdapter
 * @public
 */
class EventBridgeAdapter {
    //#region Constructor
    /**
     * Default constructor
     *
     * @param options - The options to customize the {@link EventBridgeAdapter}
     */
    constructor(options) {
        this.options = options;
    }
    //#endregion
    //#region Public Methods
    /**
     * {@inheritDoc}
     */
    getAdapterName() {
        return EventBridgeAdapter.name;
    }
    /**
     * {@inheritDoc}
     */
    canHandle(event) {
        const eventBridgeEvent = event;
        // thanks to @cnuss in https://github.com/vendia/serverless-express/blob/b5da6070b8dd2fb674c1f7035dd7edfef1dc83a2/src/event-sources/utils.js#L87
        return !!(eventBridgeEvent &&
            eventBridgeEvent.version &&
            eventBridgeEvent.version === '0' &&
            eventBridgeEvent.id &&
            eventBridgeEvent['detail-type'] &&
            eventBridgeEvent.source &&
            eventBridgeEvent.account &&
            eventBridgeEvent.time &&
            eventBridgeEvent.region &&
            eventBridgeEvent.resources &&
            Array.isArray(eventBridgeEvent.resources) &&
            eventBridgeEvent.detail &&
            typeof eventBridgeEvent.detail === 'object' &&
            !Array.isArray(eventBridgeEvent.detail));
    }
    /**
     * {@inheritDoc}
     */
    getRequest(event) {
        var _a, _b;
        const path = (0, core_1.getDefaultIfUndefined)((_a = this.options) === null || _a === void 0 ? void 0 : _a.eventBridgeForwardPath, '/eventbridge');
        const method = (0, core_1.getDefaultIfUndefined)((_b = this.options) === null || _b === void 0 ? void 0 : _b.eventBridgeForwardMethod, 'POST');
        const [body, contentLength] = (0, core_1.getEventBodyAsBuffer)(JSON.stringify(event), false);
        const headers = {
            host: 'events.amazonaws.com',
            'content-type': 'application/json',
            'content-length': String(contentLength),
        };
        return {
            method,
            headers,
            body,
            path,
        };
    }
    /**
     * {@inheritDoc}
     */
    getResponse() {
        return core_1.EmptyResponse;
    }
    /**
     * {@inheritDoc}
     */
    onErrorWhileForwarding({ error, delegatedResolver, }) {
        delegatedResolver.fail(error);
    }
}
exports.EventBridgeAdapter = EventBridgeAdapter;
EventBridgeAdapter.__type = [() => __ΩEventBridgeOptions, 'options', 'constructor', 'getAdapterName', 'event', 'canHandle', () => __ΩEventBridgeEventAll, () => __ΩAdapterRequest, 'getRequest', () => __ΩIEmptyResponse, 'getResponse', () => __ΩOnErrorProps, () => __ΩEventBridgeEventAll, () => __ΩIEmptyResponse, 'param0', 'onErrorWhileForwarding', () => __ΩEventBridgeEventAll, () => __ΩIEmptyResponse, 'Pn!2"8<9"0#P&0$P#2%!0&Pn\'2%n(0)Pn*0+Pn-n.o,#2/$005n1"n26$'];
//# sourceMappingURL=event-bridge.adapter.js.map