"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.S3Adapter = exports.__ΩS3AdapterOptions = void 0;
const { __ΩAdapterRequest } = require('../../contracts');
const { __ΩIEmptyResponse } = require('../../core');
const { __ΩOnErrorProps } = require('../../contracts');
const core_1 = require("../../core");
const __ΩS3AdapterOptions = ['s3ForwardPath', 's3ForwardMethod', 'P&4!8&4"8M'];
exports.__ΩS3AdapterOptions = __ΩS3AdapterOptions;
/**
 * The adapter to handle requests from AWS S3.
 *
 * The option of `responseWithErrors` is ignored by this adapter and we always call `resolver.fail` with the error.
 *
 * {@link https://docs.aws.amazon.com/pt_br/lambda/latest/dg/with-s3.html | Event Reference}
 *
 * @example
 * ```typescript
 * const s3ForwardPath = '/your/route/s3'; // default /s3
 * const s3ForwardMethod = 'POST'; // default POST
 * const adapter = new S3Adapter({ s3ForwardPath, s3ForwardMethod });
 * ```
 *
 * @breadcrumb Adapters / AWS / S3Adapter
 * @public
 */
class S3Adapter {
    //#region Constructor
    /**
     * Default constructor
     *
     * @param options - The options to customize the {@link S3Adapter}
     */
    constructor(options) {
        this.options = options;
    }
    //#endregion
    //#region Public Methods
    /**
     * {@inheritDoc}
     */
    getAdapterName() {
        return S3Adapter.name;
    }
    /**
     * {@inheritDoc}
     */
    canHandle(event) {
        var _a;
        const s3Event = event;
        if (!Array.isArray(s3Event === null || s3Event === void 0 ? void 0 : s3Event.Records))
            return false;
        const eventSource = (_a = s3Event.Records[0]) === null || _a === void 0 ? void 0 : _a.eventSource;
        return eventSource === 'aws:s3';
    }
    /**
     * {@inheritDoc}
     */
    getRequest(event) {
        var _a, _b;
        const path = (0, core_1.getDefaultIfUndefined)((_a = this.options) === null || _a === void 0 ? void 0 : _a.s3ForwardPath, '/s3');
        const method = (0, core_1.getDefaultIfUndefined)((_b = this.options) === null || _b === void 0 ? void 0 : _b.s3ForwardMethod, 'POST');
        const [body, contentLength] = (0, core_1.getEventBodyAsBuffer)(JSON.stringify(event), false);
        const headers = {
            host: 's3.amazonaws.com',
            'content-type': 'application/json',
            'content-length': String(contentLength),
        };
        return {
            method,
            headers,
            body,
            path,
        };
    }
    /**
     * {@inheritDoc}
     */
    getResponse() {
        return core_1.EmptyResponse;
    }
    /**
     * {@inheritDoc}
     */
    onErrorWhileForwarding({ error, delegatedResolver, }) {
        delegatedResolver.fail(error);
    }
}
exports.S3Adapter = S3Adapter;
S3Adapter.__type = [() => __ΩS3AdapterOptions, 'options', 'constructor', 'getAdapterName', 'event', 'canHandle', () => __ΩAdapterRequest, 'getRequest', () => __ΩIEmptyResponse, 'getResponse', () => __ΩOnErrorProps, () => __ΩIEmptyResponse, 'param0', 'onErrorWhileForwarding', () => __ΩIEmptyResponse, 'Pn!2"8<9"0#P&0$P#2%!0&P"2%n\'0(Pn)0*P"n,o+#2-$0.5""n/6$'];
//# sourceMappingURL=s3.adapter.js.map