"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SNSAdapter = exports.__ΩSNSAdapterOptions = void 0;
const { __ΩAdapterRequest } = require('../../contracts');
const { __ΩIEmptyResponse } = require('../../core');
const { __ΩOnErrorProps } = require('../../contracts');
const core_1 = require("../../core");
const __ΩSNSAdapterOptions = ['snsForwardPath', 'snsForwardMethod', 'P&4!8&4"8M'];
exports.__ΩSNSAdapterOptions = __ΩSNSAdapterOptions;
/**
 * The adapter to handle requests from AWS SNS.
 *
 * The option of `responseWithErrors` is ignored by this adapter and we always call `resolver.fail` with the error.
 *
 * {@link https://docs.aws.amazon.com/pt_br/lambda/latest/dg/with-sns.html | Event Reference}
 *
 * @example
 * ```typescript
 * const snsForwardPath = '/your/route/sns'; // default /sns
 * const snsForwardMethod = 'POST'; // default POST
 * const adapter = new SNSAdapter({ snsForwardPath, snsForwardMethod });
 * ```
 *
 * @breadcrumb Adapters / AWS / SNSAdapter
 * @public
 */
class SNSAdapter {
    //#region Constructor
    /**
     * Default constructor
     *
     * @param options - The options to customize the {@link SNSAdapter}
     */
    constructor(options) {
        this.options = options;
    }
    //#endregion
    //#region Public Methods
    /**
     * {@inheritDoc}
     */
    getAdapterName() {
        return SNSAdapter.name;
    }
    /**
     * {@inheritDoc}
     */
    canHandle(event) {
        var _a;
        const snsEvent = event;
        if (!Array.isArray(snsEvent === null || snsEvent === void 0 ? void 0 : snsEvent.Records))
            return false;
        const eventSource = (_a = snsEvent.Records[0]) === null || _a === void 0 ? void 0 : _a.EventSource;
        return eventSource === 'aws:sns';
    }
    /**
     * {@inheritDoc}
     */
    getRequest(event) {
        var _a, _b;
        const path = (0, core_1.getDefaultIfUndefined)((_a = this.options) === null || _a === void 0 ? void 0 : _a.snsForwardPath, '/sns');
        const method = (0, core_1.getDefaultIfUndefined)((_b = this.options) === null || _b === void 0 ? void 0 : _b.snsForwardMethod, 'POST');
        const [body, contentLength] = (0, core_1.getEventBodyAsBuffer)(JSON.stringify(event), false);
        const headers = {
            host: 'sns.amazonaws.com',
            'content-type': 'application/json',
            'content-length': String(contentLength),
        };
        return {
            method,
            headers,
            body,
            path,
        };
    }
    /**
     * {@inheritDoc}
     */
    getResponse() {
        return core_1.EmptyResponse;
    }
    /**
     * {@inheritDoc}
     */
    onErrorWhileForwarding({ error, delegatedResolver, }) {
        delegatedResolver.fail(error);
    }
}
exports.SNSAdapter = SNSAdapter;
SNSAdapter.__type = [() => __ΩSNSAdapterOptions, 'options', 'constructor', 'getAdapterName', 'event', 'canHandle', () => __ΩAdapterRequest, 'getRequest', () => __ΩIEmptyResponse, 'getResponse', () => __ΩOnErrorProps, () => __ΩIEmptyResponse, 'param0', 'onErrorWhileForwarding', () => __ΩIEmptyResponse, 'Pn!2"8<9"0#P&0$P#2%!0&P"2%n\'0(Pn)0*P"n,o+#2-$0.5""n/6$'];
//# sourceMappingURL=sns.adapter.js.map