"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDefaultIfUndefined = void 0;
/**
 * Return the defaultValue whether the value is undefined, otherwise, return the value.
 *
 * @example
 * ```typescript
 * const value1 = getDefaultIfUndefined(undefined, true);
 * const value2 = getDefaultIfUndefined(false, true);
 *
 * console.log(value1);
 * // true
 * console.log(value2);
 * // false
 * ```
 *
 * @param value - The value to be checked
 * @param defaultValue - The default value when value is undefined
 *
 * @breadcrumb Core
 * @public
 */
function getDefaultIfUndefined(value, defaultValue) {
    if (typeof value === 'undefined')
        return defaultValue;
    return value;
}
exports.getDefaultIfUndefined = getDefaultIfUndefined;
getDefaultIfUndefined.__type = ['value', 'defaultValue', 'getDefaultIfUndefined', 'PP"-J2!"2""/#'];
//# sourceMappingURL=optional.js.map